Learn R Programming

infoelectoral (version 1.0.1)

candidatos_nosenado: candidatos_nosenado

Description

`candidatos_nosenado()` downloads, formats and imports to the environment the data of the candidates from the electoral lists of the selected elections.

Usage

candidatos_nosenado(tipo, anno, mes)

Value

data.frame with the data of candidates.

Arguments

tipo

Code for the type of election.

anno

The year of the election in YYYY format.

mes

The month of the election in MM format.