codigos_municipios: Administrative codes for spanish municipalities.

codigos_municipiosR Documentation

Administrative codes for spanish municipalities.

Description

This dataset contains the INE codes of the municipalities of Spain with their most recent names (eg: Cabrera d'Igualada appears as Cabrera d'Anoia). For the municipalities that have been merged at some point, their codes are kept separately along with that of the new municipality created (eg: it contains the municipality Oza-Cesuras but also that of Cesuras and Oza dos Ríos separately).

Usage

codigos_municipios

Format

A dataset with more than 8.000 rows and 3 columns:

codigo_provincia

Code given to the provinces by the National Institute of Statistics

codigo_municipio

Code given to the municipalities by the National Institute of Statistics

municipio

Most recent official name of the municipality

National Statistics Institute (INE) municipality code portal.


infoelectoral documentation built on April 29, 2026, 9:07 a.m.