Learn R Programming

infoelectoral (version 1.0.1)

read07: Reads the basic data files for the area superior to the municipality (provinces, islands, etc...)

Description

Reads the basic data files for the area superior to the municipality (provinces, islands, etc...)

Usage

read07(file, tempd)

Value

data.frame

Arguments

file

Path to the .DAT file that begins with 07.