Learn R Programming

infoelectoral (version 1.0.1)

read08: Reads the candidacy files at the area superior to the municipality (provinces, islands, etc...)

Description

Reads the candidacy files at the area superior to the municipality (provinces, islands, etc...)

Usage

read08(file, tempd)

Value

data.frame

Arguments

file

Path to the .DAT file that begins with 08.