Learn R Programming

infoelectoral (version 1.0.1)

read10: Reads the candidacy info at polling station level files

Description

Reads the candidacy info at polling station level files

Usage

read10(file, tempd)

Value

data.frame

Arguments

file

Path to the .DAT file that begins with 10.