`candidatos_senado()` downloads, formats and imports to the environment the data of the Senate candidates of the selected elections.
candidatos_senado(anno, mes, nivel)data.frame with the data for the Senate candidates.
The year of the election in YYYY format.
The month of the election in MM format.
The administrative level for which the data is wanted ("mesa" for polling stations or "municipio" for municipalities).