powered by
`mesas()` downloads, formats and imports to the environment the electoral results data of the selected election at the polling station level.
mesas(tipo_eleccion, anno, mes)
data.frame with the electoral results data at the polling station level.
The type of choice you want to download. The accepted values are "congreso", "senado", "europeas" o "municipales".
The year of the election in YYYY format.
The month of the election in MM format.
# \donttest{ data <- mesas(tipo_eleccion = "congreso", anno = "2023", mes = "07") str(data) # }
Run the code above in your browser using DataLab