provincias: Download data at the electoral constituency level (province or island)
Description
`provincias()` downloads, formats and imports to the environment the electoral results data of the selected election at electoral constituency level (province or island).
Usage
provincias(tipo_eleccion, anno, mes)
Value
data.frame with the electoral results data at the polling station level.
Arguments
tipo_eleccion
The type of choice you want to download. The accepted values are "congreso", "senado", "europeas" o "municipales".
ua <- "Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko)"options(HTTPUserAgent = ua)
data <- provincias(tipo_eleccion = "congreso", anno = "1982", mes = "10")
str(data)